Crate signed_distance_field

Crate signed_distance_field 

This crate approximates a signed distance field, given a binary image, as described in “The dead reckoning signed distance transform” by George J. Grevara (2004).

Modules

binary_image
distance_field
prelude

Functions

compute_distance_field
Compute the signed distance field of the specified binary image with the specified distance storage.
compute_f16_distance_field
Compute the signed distance field of the specified binary image with an f16 distance storage.
compute_f32_distance_field
Compute the signed distance field of the specified binary image with an f32 distance storage.