This crate approximates a signed distance field, given a binary image, as described in “The dead reckoning signed distance transform” by George J. Grevara (2004).
Modules
Functions
- compute_
distance_ field - Compute the signed distance field of the specified binary image with the specified distance storage.
- compute_
f16_ distance_ field - Compute the signed distance field of the specified binary image with an
f16distance storage. - compute_
f32_ distance_ field - Compute the signed distance field of the specified binary image with an
f32distance storage.