pub struct BinaryByteSliceImage<'b> { /* private fields */ }Expand description
An image which is described by a row major slice of bytes, with one byte per pixel. To determine if a byte is inside or outside, it is compared to a threshold. The default threshold is 127.